#include <unistd.h>
#include <stdio.h>
#include <sys/select.h>
#include <termios.h>
#include "input.h"

#define STDIN_FILENO   0    /* stdin */

static struct termios tio_orig;
static int getch2_status = 0;
static int flag_bg = FALSE;

int getch2_getbgflag()
{
    return flag_bg;
}

void getch2_setbgflag(int f)
{
    /* ? race condition with getch2_read() ? */
    flag_bg = f;
}

void getch2_enable()
{
    struct termios tio_new;

    tcgetattr(0, &tio_orig);

    tio_new             = tio_orig;
    tio_new.c_lflag    &= ~(ICANON | ECHO); /* Clear ICANON and ECHO. */
    tio_new.c_cc[VMIN]  = 1;
    tio_new.c_cc[VTIME] = 0;

    tcsetattr(0, TCSANOW, &tio_new);
    getch2_status = 1;
}


void getch2_disable()
{
    if (!getch2_status)
        return; // already disabled / never enabled
    tcsetattr(0, TCSANOW, &tio_orig);
    getch2_status = 0;
}


/* read a key stroke with hitting ENTER key         *
 * input                                            *
 *      time - timeout interval in millisecond   *
 * return                                           *
 *      0    - timeout                              *
 *      0xFF - select/read error                    */

char getch2_read(int time)
{
    struct timeval tv, *time_val;
    fd_set fds;
    int    retval;
    char   ch = 0;

    FD_ZERO(&fds);
    FD_SET(STDIN_FILENO, &fds);

    if (time >= 0) {
        tv.tv_sec = time / 1000;
        tv.tv_usec = (time % 1000) * 1000;
        time_val = &tv;
    } else
        time_val = NULL;


    if ((retval = select(1, &fds, NULL, NULL, time_val)) == -1) {
        perror("select()");
        ch = 0xFF;
    } else if (retval && flag_bg == FALSE) {
        if (read(STDIN_FILENO, &ch, 1) < 1)
            ch = 0xFF;
    }
    /* else
     *      timeout */

    return ch;
}

