/*
 *  ======== ceapp.c ========
 *  The CodecEngine-using part of the Linux application, separated from the
 *  rest of the Linux app to simplify the interface towards the rest of
 *  the main app. CodecEngine API and especially APIs for individual codecs
 *  are much more capable than what we need for simple (dummy) video
 *  encode/decode.
 */

/* Standard Linux headers */
#include <stdio.h>   // always include stdio.h
#include <stdlib.h>  // always include stdlib.h
#include <string.h>  // memset, memcpy, strcmp, strcpy

/* include various CodecEngine header files */
#include <xdc/std.h>
#include <ti/sdo/ce/Engine.h>
#include <ti/sdo/ce/video2/viddec2.h>
#include <ti/sdo/ce/audio/auddec.h>
#include <ti/sdo/ce/osal/Memory.h>
#include <ti/sdo/ce/CERuntime.h>
#include <ti/sdo/ce/trace/gt.h>


/*  define handles to the CodecEngine and codecs to be used across ceapp_*
 *  function calls; we are not reentrant.
 */
static String engineName = "GstEngine";

/* trace info: module name, mask */
#define MOD_NAME "ti.sdo.ce.examples.apps.video2_copy"
GT_Mask curMask = {0,0};

/*
 *  ======== ceapp_init ========
 */
void __libce_dummy(void)
{
    char *buf;
    int bufSize = 0;

    Engine_Handle engineHandle  = NULL;
    VIDDEC2_Handle viddecHandle = NULL;

    VIDDEC2_InArgs           vid_inArgs;    
    VIDDEC2_OutArgs          vid_outArgs;
    XDM1_BufDesc             inVidBufDesc;
    XDM_BufDesc              inAudBufDesc;
    XDM_BufDesc              outBufDesc;    
    VIDDEC2_Status vid_status;
    VIDDEC2_DynamicParams vid_dynParams;

    /* initialize Codec Engine runtime first */
    CERuntime_init();
    GT_init();
    GT_create(&curMask, MOD_NAME);
    GT_set(MOD_NAME "=01234567");
    GT_0trace(curMask, GT_2CLASS, "main> " MOD_NAME "\n");
    engineHandle = Engine_open(engineName,NULL,NULL);

    viddecHandle = VIDDEC2_create(engineHandle, "invalid", NULL);
    VIDDEC2_process(viddecHandle, &inVidBufDesc, &outBufDesc, &vid_inArgs, &vid_outArgs);
    VIDDEC2_control(viddecHandle, XDM_GETSTATUS, &vid_dynParams, &vid_status);
    VIDDEC2_delete(viddecHandle);

    Engine_close(engineHandle);
    buf = (char *)Memory_alloc(bufSize, NULL);
    Memory_free(buf, bufSize, NULL);
}


