#!/bin/sh
# Download opensource packages for gstreamer on TI DM355
# The packages will be downloaded, uncompressed and patched

SRC='http://ftp.gnome.org/pub/gnome/sources/glib/2.16/glib-2.16.5.tar.bz2
     http://liboil.freedesktop.org/download/liboil-0.3.15.tar.gz
     http://voxel.dl.sourceforge.net/sourceforge/check/check-0.9.5.tar.gz
     ftp://ftp.mars.org/pub/mpeg/libid3tag-0.15.1b.tar.gz
     ftp://ftp.mars.org/pub/mpeg/libmad-0.15.1b.tar.gz
     http://gstreamer.freedesktop.org/src/gstreamer/gstreamer-0.10.20.tar.bz2
     http://gstreamer.freedesktop.org/src/gst-plugins-base/gst-plugins-base-0.10.20.tar.bz2
     http://gstreamer.freedesktop.org/src/gst-plugins-good/gst-plugins-good-0.10.8.tar.bz2
     http://gstreamer.freedesktop.org/src/gst-plugins-ugly/gst-plugins-ugly-0.10.8.tar.bz2'
tmpdir=tmp

if [ "$1" = "-h" -o "$1" = "--help" ];then
    echo 'Download opensource packages for gstreamer on TI DM355'
    echo 'All packages will be downloaded to ./tmp directory,'
    echo 'uncompressed to current directory, and patches will be applied'
    echo ''
    echo 'Options:'
    echo '    -l,--list             list packages will be downloaded'
    echo '    -nd,--no-download     only uncompress and patch'
    echo '    -h, --help            print this message'
    exit 0
fi

if [ "$1" = '-l' -o "$1" = "--list" ]; then
    for p in $SRC; do
        echo $p
    done
    exit 0
fi

if [ -z "$1" ]; then
    which wget > /dev/null || { echo "ERROR: cannot find command 'wget'"; exit 1; }
    echo 'downloading...'

    mkdir -p $tmpdir
    for p in $SRC; do
        wget -t2 -P${tmpdir} $p
    done
else
    [ "$1" = "-nd" -o "$1" = "--no-download" ] ||
        { echo "Error: unknown options - $1"; exit 3; }
fi


which tar > /dev/null || { echo "ERROR: cannot find command 'tar'"; exit 2; }
for p in ${tmpdir}/*; do
    if [ ${p%*.bz2} != $p ]
    then OPT=jxf
    else OPT=zxf
    fi
    echo "uncompressing $p..."
    tar $OPT $p || { echo 'Error: uncompress failed'; exit 3; }
done

which patch > /dev/null || { echo "ERROR: cannot find command 'patch'"; exit 4; }
echo 'patching...'
patch -p0 < patches/gstosssink.c.diff
patch -p0 < patches/gstmad.c.diff
