#!/bin/sh

# script to compile gstreamer opensource dependencies
#
# Usage:  ./make-os.sh [packages...]
#           packages - any of glib check gst liboil base good ugly,
#                      separated by which space. order does not matter
#           Without option will compile all packages

. ../build.conf

#Location of Gstreamer package config path 
export PKG_CONFIG_PATH=${GST_PREFIX}/lib/pkgconfig

OS_TOPDIR=$PWD
CC=${CROSS_COMPILE}gcc
COMM_OPT="--build=i686-linux --host=arm-linux --prefix=${GST_PREFIX}"

if [ -z "$1" ]; then
    build_glib="y"
    build_check="y"
    build_gst="20"
    build_liboil="y"
    build_gstbase="20"
    build_gstgood="8"   # for osssink & avidemux
    build_gstugly="8"   # for mad
else
    while [ -n "$1" ]; do
        case "$1" in
          glib) build_glib="y";;
         check) build_check="y";;
           gst) build_gst="20";;
        liboil) build_liboil="y";;
          base) build_gstbase="20";;
          good) build_gstgood="8";;
          ugly) build_gstugly="8";;
             *) echo "unknown option: $1"; exit 1
        esac

        shift 1
    done
fi


if [ "$build_glib" = "y" ]; then
    glib-genmarshal --help 2>&1 | grep '\--internal' > /dev/null || {
        echo 'Error: glib-genmarshal does not supprt --internal option'
        echo 'Please upgrade to newer version'
        exit 1;
    }

    cd "$OS_TOPDIR/glib-2.16.5" &&
    CC=$CC ./configure $COMM_OPT glib_cv_stack_grows=no \
        glib_cv_uscore=no glib_cv_monotonic_clock=no \
        ac_cv_func_posix_getpwuid_r=yes ac_cv_func_posix_getgrgid_r=yes \
        --without-libiconv --disable-selinux --disable-fam --disable-xattr &&
    sed -e '/HAVE_CLOCK_GETTIME/d' config.h > config.h.$ &&
    mv -f config.h.$ config.h &&
    make clean && make install || exit $?
fi

if [ "$build_check" = "y" ]; then
    cd "$OS_TOPDIR/check-0.9.5" &&
    CC=$CC ./configure $COMM_OPT ac_cv_func_malloc_0_nonnull=yes \
       ac_cv_func_realloc_0_nonnull=yes &&
    make clean && make install || exit $?
fi

if [ "$build_gst" != "" ]; then
    cd "$OS_TOPDIR/gstreamer-0.10.$build_gst" &&
    CC=$CC ./configure $COMM_OPT CFLAGS=-I"$GST_PREFIX/include" \
        --with-checklibname=check --disable-tests --disable-examples \
        --disable-nls --disable-loadsave --disable-valgrind --disable-net &&
    cd .. && patch -p0 < patches/gstconfig.h.diff && 
    cd - &&  make clean && make install || exit $?
fi

if [ "$build_liboil" = "y" ]; then
    cd "$OS_TOPDIR/liboil-0.3.15" &&
    CC=$CC ./configure $COMM_OPT &&
    make clean && make install || exit $?
fi

if [ "$build_gstbase" != "" ]; then
    cd "$OS_TOPDIR/gst-plugins-base-0.10.$build_gstbase" &&
    CC=$CC ./configure $COMM_OPT --with-checklibname=check \
        --disable-tests --disable-examples --disable-nls \
        --disable-valgrind --disable-external --with-plugins=playback &&
    make clean && make install || exit $?
fi


if [ "$build_gstgood" != "" ]; then
    cd "$OS_TOPDIR/gst-plugins-good-0.10.$build_gstgood" &&
    CFLAGS="-I${GST_PREFIX}/include" CC=$CC ./configure $COMM_OPT \
        --with-checklibname=check --disable-examples --disable-nls \
        --disable-valgrind --disable-schemas-install --with-plugins=avi \
        --disable-aalib --disable-annodex --disable-esd --disable-x \
        --disable-jpeg --disable-libcaca --disable-libpng --disable-shout2 \
        --disable-taglib && 
    make clean && make install || exit $?
fi


if [ "$build_gstugly" != "" ]; then
    cd "$OS_TOPDIR/libid3tag-0.15.1b" &&
        CC=$CC ./configure $COMM_OPT &&
        make clean && make install || exit $?
    cp -af $OS_TOPDIR/patches/id3tag.pc $PKG_CONFIG_PATH/ || exit $?

    cd "$OS_TOPDIR/libmad-0.15.1b" &&
        CC=$CC ./configure $COMM_OPT --enable-fpm=arm --enable-speed \
        --disable-debugging && make clean && make install || exit $?
    cp -af $OS_TOPDIR/patches/mad.pc $PKG_CONFIG_PATH/ || exit $?

    cd "$OS_TOPDIR/gst-plugins-ugly-0.10.$build_gstugly" &&
    CFLAGS="-I${GST_PREFIX}/include -DENABLE_16BIT_SUPPORT" CC=$CC \
    ./configure $COMM_OPT --disable-tests --with-checklibname=check \
        --disable-nls --disable-examples --disable-valgrind \
        --with-plugins=none &&
    make clean && make install || exit $?
fi


# compiling madplay
# CC=arm_v5t_le-gcc ./configure --build=i686-linux --host=arm-linux --prefix=/dm355_dev/tgtfs/usr/local CFLAGS='-I/dm355_dev/tgtfs/usr/local/include/' LIBS='-L/dm355_dev/tgtfs/usr/local/lib'

