/*
 * Plugin Name : gstvdec.h
 * Description : Header file for Video Decoder for for TI DM3xx
 *
 * Copyright (C) 2008 Texas Instruments, Inc.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation version 2.1 of the License.
 *
 * This program is distributed "as is" WITHOUT ANY WARRANTY of any kind,
 * whether express or implied; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 */
#ifndef __GST_VDEC_H__
#define __GST_VDEC_H__

#ifdef __cplusplus
extern "C" {
#endif

#include <stdio.h>
#include <string.h>
#include <stdlib.h>

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <pthread.h>
#include <getopt.h>
#include <errno.h>
#include <glib.h>
#include <gst/gst.h>
#include <gst/base/gstadapter.h>

#define 	IDMA3_USEFULLPACKAGEPATH
#define 	MdUns   	UInt16
#define 	SmUns   	UInt8

#include <xdc/std.h>
#include <ti/sdo/ce/video2/viddec2.h>
#include <ti/sdo/ce/CERuntime.h>
#include <ti/sdo/ce/Engine.h>
#include <ti/sdo/ce/trace/gt.h>
#include <ti/sdo/ce/osal/Memory.h>
#include <ti/xdais/idma3.h>

#define CLOCK_BASE 9LL
#define CLOCK_FREQ CLOCK_BASE * 10000

#define BUFFER_SIZE             80*1024
#define NUM_BUFS                40
#define BUF_POOL_SIZE           BUFFER_SIZE*NUM_BUFS

/* Begin Declaration */
G_BEGIN_DECLS

#define GST_TYPE_VDEC	   	     	(gst_vdec_get_type())
#define GST_TYPE_VDEC_ENGINE		(gst_vdec_get_engine_type())
#define GST_TYPE_VDEC_CODEC			(gst_vdec_get_codec_type())
#define GST_VDEC(obj)		     	(G_TYPE_CHECK_INSTANCE_CAST((obj),GST_TYPE_VDEC,GstVDec))
#define GST_VDEC_CLASS(klass)     	(G_TYPE_CHECK_CLASS_CAST((klass),GST_TYPE_VDEC,GstVDecClass))
#define GST_VDEC_GET_CLASS(klass) 	(G_TYPE_INSTANCE_GET_CLASS((klass),GST_TYPE_VDEC,GstVDecClass))
#define GST_IS_VDEC(obj)		    (G_TYPE_CHECK_INSTANCE_TYPE((obj),GST_TYPE_VDEC))
#define GST_IS_VDEC_CLASS(obj)	 	(G_TYPE_CHECK_CLASS_TYPE((klass),GST_TYPE_VDEC))

typedef struct _GstVDec GstVDec;
typedef struct _GstVDecClass GstVDecClass;

struct _GstVDec {
    GstElement parent;

    GstPad *sinkpad;
    GstPad *srcpad;

    gboolean decReady;
    gboolean padBufAlloc;
    guint8 codec;
    guint8 engine;
    gchar *engineName;

    gboolean isCodecPropSet;

//    XDAS_Int8 *outbuf;
    XDM_BufDesc outBufDesc;
    XDM1_BufDesc inBufDesc;
    XDAS_Int32 inBufSize;   //For free
//    guint32 curInBufStartOffset;
//    guint64 ptsNoDemux;
    guint32 firstFrame;
    void *decoder;
    Engine_Handle ce;
    GstSegment segment;
    GstBuffer *sinkbuf;
    GstBuffer *srcbuf;
    gboolean streaming;
    guint32 width;
    guint32 height;
//    gboolean isRcv;
    gboolean isEof;
//    guint64 bytesConsumed;
    gchar *bufPoolBase;
    gint poolFreeSize;
    guint poolNextFreeOffset;
    guint poolCurRequest;
    GQueue *poolSizeq;
    GMutex *pool_mutex;
    GMutex *freesize_mutex;
    GCond *pool_cond;
};

struct _GstVDecClass {
    GstElementClass parent_class;
    GstPadTemplate *sink_template;
    GstPadTemplate *src_template;
};

GType gst_vdec_get_type(void);

void gst_vdec_reset(GstVDec * vdec);
void gst_vdec_cleanup(GstVDec * vdec);

G_END_DECLS
#endif                          /* __GST_VDEC_H__ */
